#
# spec file for package gap-digraphs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-digraphs
Version:        1.9.0
Release:        1.3
Summary:        GAP: Digraphs and multigraphs
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://digraphs.github.io/Digraphs/
#Git-Clone:     https://github.com/digraphs/Digraphs
Source:         https://github.com/digraphs/Digraphs/releases/download/v%version/digraphs-%version.tar.gz
BuildRequires:  edge-addition-planarity-suite-devel
BuildRequires:  fdupes
BuildRequires:  gap-devel
BuildRequires:  gap-rpm-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
Requires:       gap-core >= 4.10
Requires:       gap-datastructures >= 0.2.5
Requires:       gap-io >= 4.5.1
Requires:       gap-orb >= 4.8.2
Suggests:       gap-autodic >= 2022.08.11
Suggests:       gap-gapdoc >= 1.6.3
Suggests:       gap-grape >= 4.8.1
Suggests:       gap-nautytracesinterface >= 0.2
# Source contains a modified copy of bliss-0.73, so we cannot reuse bliss-devel
Provides:       bundled(bliss) = 0.73

%description
The Digraphs package is a GAP package containing methods for digraphs
and multidigraphs.

%prep
%autosetup -n digraphs-%version

%build
%configure --with-gaproot="%gapdir" --without-intrinsics \
	--with-external-planarity
%make_build
find . -type f -name "*~" -print -delete

%install
%gappkg_simple_install
pushd "%buildroot/$fmoddir/"
find . -type f -name .dirstamp -print -delete
# delete tests and assets
rm -Rf tst data/symmetric-closure.ds6.gz data/test-1.d6
# delete sources and build artifacts, user is not expected to rebuild in distribution tree
rm -Rf autom4te.cache src cnf config* m4 autogen.sh aclocal.m4 *.la Makefile*
rm -Rf extern/edge* extern/bliss*/[a-z]* extern/bliss*/.deps extern/bliss*/.libs extern/bliss*/.clang*
popd
%fdupes %buildroot/%_prefix

%files -f %name.files

%changelog
* Sun Sep  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.9.0
  * Fix off by one error [#677]
  * Properly transfer the original vertices as labels of the
    vertices in the reduced graph in ``DigraphAllSimpleCircuits``
  * Add hash function for digraphs [#675]
  * Add DomainForAction mock for actions on digraphs [#686]
  * Make Orb use digraph hashes [#687]
  * Added ``DigraphAllChordlessCycles`` [#679],
    ``SubdigraphsMonomorphisms`` [#690],
    ``AllUndirectedSimpleCircuits`` [#689]
  * Fix edge placement in ``HanoiGraph`` [#699]
  * Clarify homomorphisms finder with specified image [#700]
* Tue Aug 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.0
  * DigraphRemoveEdge now removes appropriate edge label
  * Implement IsOrderIdeal, DigraphCycleBasis,
    IsModularLatticeDigraph, DigraphContractEdge
  * cliques: some performance improvements
  * Refactored Floyd–Warshall C implementation
  * Added requested clique and independent attributes
  * Reduce memory usage
* Mon Feb 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7.1
  * Unspecified changes related to forthcoming changes in the
    GAP core.
* Wed Feb 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7.0
  * Add immediate methods for connected and strongly connected
    graphs
  * kernel: fix mem leaks for permutations allocated but not
    freed.
  * Added EdgeWeightedDigraph, AbsorptionExpectedSteps,
    DigraphAbsorptionProbabilities
* Fri Sep 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.3
  * Standardise the way that UndirectedSpanningForest works in
    relation to mutability
  * Add immediate methods for connected and strongly connected
    digraphs
* Wed Apr  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.2
  * Janitorial changes
* Tue Dec 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.1
  * Change `CayleyDigraph` to use `AsSet`
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * The `ViewString` for immutable digraphs attempts to show more
    of the known information about the digraph. This will break tests
    that relied on the previous behaviour, that contained only the
    numbers of vertices and edges.
  * The behaviour of `QuotientDigraph` has been changed so that it
    no longer returns digraphs with multiple edges.
  * `IsEulerianDigraph` would previously return `true` for digraphs
    that are Eulerian when their isolated vertices were removed,
    which contradicted the documentation. `IsEulerianDigraph` now
    returns `false` for _all_ digraphs that are not strongly
    connected.
- Delete 0001-Drop-bad-include-of-x86intrin.h.patch,
  digraphs-no-native.diff
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.13
  * The GraphViz engine used by `Splash` is now configurable
  * The properties `IsPartialOrderDigraph`, `IsPreorderDigraph`,
    and IsQuasiorderDigraph` were introduced, along with the
    following functions for visualising these kinds of digraphs:
    `DotPartialOrderDigraph`, `DotPreorderDigraph`,
    `DotQuasiorderDigraph`.
  * The following functions for transformations and permutations
    were added `IsDigraphHomomorphism`, `IsDigraphEpimorphism`,
    `IsDigraphMonomorphism`, `IsDigraphEndomorphism`,
    `IsDigraphEmbedding`, `IsDigraphIsomorphism`.
* Fri Oct 19 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.12
  * Fixed a bug in `ArticulationPoints` and `IsBiconnectedDigraph`.
  * Added the property `IsChainDigraph`.
  * Added the operation `IsDigraphAutomorphism`.
  * Fixed: `HomomorphismDigraphFinder` sometimes failed to find a
    homomorphism when one existsed.
  * Fixed: A segmentation fault could be caused when using Digraphs
    with NautyTracesInterface, in certain cases.
* Fri Jan 26 2018 stefan.bruens@rwth-aachen.de
- Remove all transient build artifacts (e.g. config.log) to make
  build reproducible
- delete remaining sources and test assets
* Fri Jan 26 2018 stefan.bruens@rwth-aachen.de
- Add 0001-Drop-bad-include-of-x86intrin.h.patch
  Remove unnecessary include of x86intrin.h, breaks compilation on
  anything but x86.
* Fri Jan 26 2018 guillaume@opensuse.org
- Add ExclusiveArch for x86 and x86_64 since it needs 'x86intrin.h'
* Sat Dec 23 2017 jengelh@inai.de
- Update to new upstream release 0.11.0
  * Support for computing automorphisms, canonical labellings,
    and isomorphisms of digraphs with "nauty". This functionality
    requires the gap-nautytracesinterface package for GAP.
    However, this is not a required package, and the default
    engine remains "bliss". It is possible to specify the engine
    that is used by Digraphs.
  * In particular, version 0.11.0 includes the following changes:
  * `BlissAutomorphismGroup` and `NautyAutomorphismGroup` are
    introduced.
  * `DigraphCanonicalLabelling` is replaced by
    `BlissCanonicalLabelling` and `NautyCanonicalLabelling`.
  * `BlissCanonicalDigraph` and `NautyCanonicalDigraph` are
    introduced
  * `DigraphsUseNauty` and `DigraphsUseBliss` are introduced.
  * The property `IsHamiltonianDigraph` and the attribute
    `HamiltonianPath` were added.
- Add digraphs-no-native.diff
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 0.10.1
  * This release contains new features, bugfixes, and minor
    improvements to the documentation. There is a new method for
    `ChromaticNumber`, which has better performance than the
    previous method.
  * A bug in the code for calculating homomorphisms of digraphs,
    which could cause a crash, was resolved.
  * Vertex labelled digraphs can now be visualised in a way that
    displays vertex labels, by using the new operation
    `DotVertexLabelledDigraph`.
  * The attribute `CliqueNumber` is introduced.
  * The following new attributes for Cayley digraphs are
    introduced: `GroupOfCayleyDigraph`,
    `SemigroupOfCayleyDigraph`, `GeneratorsOfCayleyDigraph`.
  * New features introduced in 0.9.0: `ArticulationPoints` (and
    its synonym `CutVertices`), `IsBiconnectedDigraph`
    `IsCycleDigraph`, `IsMatching`, `IsPerfectMatching`,
    `IsMaximalMatching`.
  * New features introduced in 0.8.0: `DigraphClosure`,
    `BooleanAdjacencyMatrixMutableCopy`, `IsPartialOrderDigraph`,
    `IsMeetSemilatticeDigraph`, `IsJoinSemilatticeDigraph`,
    `IsLatticeDigraph`, `PartialOrderDigraphMeetOfVertices`,
    `PartialOrderDigraphJoinOfVertices`.
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 0.7.1
  * This release contains a new technique for encoding a
    vertex-coloured `multidigraph` as a vertex-coloured
    (undirected) graph while preserving the automorphism group,
    in order to calculate the automorphism group and canonical
    labelling using bliss. This enables the following
    functionality:
  * * the operations `AutomorphismGroup` and
    `DigraphCanonicalLabelling` for a digraph and a
    vertex-colouring now accept a multidigraph as their first
    argument;
  * * the operations `IsIsomorphicDigraph` and
    `IsomorphismDigraphs` now accept multidigraphs, and they
    also accept vertex-colourings as optional arguments.
  * This release add new functionality related to undirected
    spanning trees and undirected spanning forests:
  * * The property `IsUndirectedForest` is introduced;
  * * The attributes `UndirectedSpanningTree` and
    `UndirectedSpanningForest` are introduced; and
  * * The operations `IsUndirectedSpanningTree` and
    `IsUndirectedSpanningForest` are introduced.
* Sun Oct 16 2016 jengelh@inai.de
- Update to new upstream release 0.5.2
  * Digraphs now works when it and GAP are built in 32-bit mode.
- Update to new upstream release 0.5.1
  * This release contains a new technique for encoding a
  vertex-coloured digraph as a vertex-coloured (undirected) graph
  while preserving the automorphism group, in order to calculate
  the automorphism group using bliss.
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 0.5
  * Unspecified bugfixes
* Fri Mar 11 2016 jengelh@inai.de
- Initial packages (version 0.4.2) for build.opensuse.org
